## Steinemann DPE
![Tests](https://github.com/SteinemannDPE/Python_Libs/actions/workflows/deploy-stdpe-lib.yml/badge.svg)

The Steinemann DPE (stdpe) library is a fast and easy to use library for the daily work.

### Main Features
**Azure**
- Working with key vault
- Working with azure storage account

**Database kit**
- Working with Microsoft SLQ database 

**Utils**
- Logging (Console/Azure)
- Dictionary utilities
- Pandas utilities
- Stopwatch
- World geodetic system (WGS 84)

